@@ -21,6 +21,7 @@ along with MoNav.  If not, see <http://www.gnu.org/licenses/>.
 #define GENERALSETTINGSDIALOG_H
 
 #include <QDialog>
+#include <QFileDialog>
 
 namespace Ui {
 	class GeneralSettingsDialog;
@@ -32,21 +33,24 @@ class GeneralSettingsDialog : public QDialog
 
 public:
 
-	enum MenuMode {
-		MenuPopup, MenuOverlay
-	};
-
 	explicit GeneralSettingsDialog( QWidget* parent = 0 );
 	~GeneralSettingsDialog();
 
-	void setIconSize( int size );
-	int iconSize();
-	void setCustomIconSize( bool custom );
-	bool customIconSize();
-	void setMenuMode( MenuMode mode );
-	MenuMode menuMode();
+	// not necessary to call after exec, as exec does this itself
+	void fillSettings() const;
+
+public slots:
+
+	int exec();
+	void setDefaultIconSize();
+	void selectPathLogging();
+
+protected slots:
+
+	void confirmClearTracklog();
 
 private:
+
 	Ui::GeneralSettingsDialog* m_ui;
 };
 
