@@ -20,27 +20,32 @@ along with MoNav.  If not, see <http://www.gnu.org/licenses/>.
 #ifndef ROUTEDESCRIPTIONDIALOG_H
 #define ROUTEDESCRIPTIONDIALOG_H
 
-#include <QDialog>
+#include <QWidget>
 #include <QStringList>
 
 namespace Ui {
 	class RouteDescriptionDialog;
 }
 
-class RouteDescriptionDialog : public QDialog
+class RouteDescriptionWidget : public QWidget
 {
 	Q_OBJECT
 
 public:
 
-	explicit RouteDescriptionDialog( QWidget *parent = 0 );
-	~RouteDescriptionDialog();
+	explicit RouteDescriptionWidget( QWidget *parent = 0 );
+	~RouteDescriptionWidget();
+
+signals:
+
+	void closed();
 
 public slots:
 
 	void instructionsChanged();
 
 protected:
+
 	Ui::RouteDescriptionDialog* m_ui;
 };
 
