@@ -39,10 +39,13 @@ public slots:
 
 protected:
 
-	virtual bool loadTile( int x, int y, int zoom, QPixmap** tile );
+	virtual void advancedSettingsChanged();
+	virtual bool loadTile( int x, int y, int zoom, int magnification, QPixmap** tile );
 	virtual bool load();
 	virtual void unload();
 
+	QString m_server;
+
 	QNetworkAccessManager* network;
 	QNetworkDiskCache* diskCache;
 	int tileSize;
